@@ -49,7 +49,7 @@ where
     /// }
     /// ```
     pub async fn list(&self, lp: &ListParams) -> Result<ObjectList<K>> {
-        let mut req = self.request.list(&lp)?;
+        let mut req = self.request.list(lp)?;
         req.extensions_mut().insert("list");
         self.client.request::<ObjectList<K>>(req).await
     }
@@ -75,7 +75,7 @@ where
         K: Serialize,
     {
         let bytes = serde_json::to_vec(&data)?;
-        let mut req = self.request.create(&pp, bytes)?;
+        let mut req = self.request.create(pp, bytes)?;
         req.extensions_mut().insert("create");
         self.client.request::<K>(req).await
     }
@@ -103,7 +103,7 @@ where
     /// }
     /// ```
     pub async fn delete(&self, name: &str, dp: &DeleteParams) -> Result<Either<K, Status>> {
-        let mut req = self.request.delete(name, &dp)?;
+        let mut req = self.request.delete(name, dp)?;
         req.extensions_mut().insert("delete");
         self.client.request_status::<K>(req).await
     }
@@ -140,7 +140,7 @@ where
         dp: &DeleteParams,
         lp: &ListParams,
     ) -> Result<Either<ObjectList<K>, Status>> {
-        let mut req = self.request.delete_collection(&dp, &lp)?;
+        let mut req = self.request.delete_collection(dp, lp)?;
         req.extensions_mut().insert("delete_collection");
         self.client.request_status::<ObjectList<K>>(req).await
     }
@@ -180,7 +180,7 @@ where
         pp: &PatchParams,
         patch: &Patch<P>,
     ) -> Result<K> {
-        let mut req = self.request.patch(name, &pp, patch)?;
+        let mut req = self.request.patch(name, pp, patch)?;
         req.extensions_mut().insert("patch");
         self.client.request::<K>(req).await
     }
@@ -234,7 +234,7 @@ where
         K: Serialize,
     {
         let bytes = serde_json::to_vec(&data)?;
-        let mut req = self.request.replace(name, &pp, bytes)?;
+        let mut req = self.request.replace(name, pp, bytes)?;
         req.extensions_mut().insert("replace");
         self.client.request::<K>(req).await
     }
@@ -281,7 +281,7 @@ where
         lp: &ListParams,
         version: &str,
     ) -> Result<impl Stream<Item = Result<WatchEvent<K>>>> {
-        let mut req = self.request.watch(&lp, &version)?;
+        let mut req = self.request.watch(lp, version)?;
         req.extensions_mut().insert("watch");
         self.client.request_events::<K>(req).await
     }
